==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-desktopswitch/desktopswitch_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../../../desktopswitch.cpp" line="84"/>
        <source>Switch to desktop %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitch.cpp" line="141"/>
        <location filename="../../../desktopswitch.cpp" line="151"/>
        <source>Desktop %1</source>
        <translation>%1 darbalaukis</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="70"/>
        <source>Desktop names</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-desktopswitch/desktopswitch_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../../../desktopswitch.cpp" line="84"/>
        <source>Switch to desktop %1</source>
        <translation>Perjungti į darbalaukį %1</translation>
    </message>
    <message>
        <location filename="../../../desktopswitch.cpp" line="141"/>
        <location filename="../../../desktopswitch.cpp" line="151"/>
        <source>Desktop %1</source>
        <translation>Darbalaukis %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation>Darbalaukių perjungiklio nustatymai</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Eilučių skaičius:</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Darbalaukių etiketės:</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Skaičiai</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Pavadinimai</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="70"/>
        <source>Desktop names</source>
        <translation>Darbalaukių pavadinimai</translation>
    </message>
</context>
</TS>
